-------------------------------------------------------------------------------
-- This is the update template file
--
-- For every hotfix/service pack there is a unique update script that is 
-- executed by the installer. 
--
-- The first statement is a logging statement to indicate what db version
-- the database currently has.
--
-- The script ends with an update statement to increment the database version
-- and another log statement to indicate completion of the update script.
-- Wrap all blocks with begin/end keywords, even if there is only one statement.
--
-- If some sql statements only need to be executed against a hosted or licensed -- database, use the dbo.isHosted() function call. This function returns 1 if 
-- the database is a hosted database and 0 if licensed, i.e. 
--	if dbo.isHosted() = 1
--		begin
--			print 'hosted';
--		end
--
--
-- Please use isBigint() function to determine if database uses bigint for IDs:
--	if dbo.isBigint() = 1
--		begin
--			print 'IDs are of BIGINT type';
--		end
-- else 
--		begin
--			print 'IDs are of INTERGER type';
--		end
-------------------------------------------------------------------------------

EXECUTE updateLogger '$Id: //depot/main/AdobeConnect/installers/patches/9.5.4_9.5.5/update_9_5_5_0.sql#2 $', '$Change: 1337535 $', 'Start';

--------------------------------------
-- Start of updates
--------------------------------------

----------------------------------------------------------------------------------------------------------------------------------
--BEGIN  Bug: CONN-4083634 - Optimize CoreDAL.createUserSession query
----------------------------------------------------------------------------------------------------------------------------------
GO
PRINT 'Processing index PPS_USER_SESSION_COOKIE...'
GO
IF NOT EXISTS(SELECT 
				T.[name] AS [table_name], I.[name] AS [index_name], AC.[name] AS [column_name],  
				I.[type_desc], I.[is_unique], I.[data_space_id], I.[ignore_dup_key], I.[is_primary_key], 
				I.[is_unique_constraint], I.[fill_factor],    I.[is_padded], I.[is_disabled], I.[is_hypothetical], 
				I.[allow_row_locks], I.[allow_page_locks], IC.[is_descending_key], IC.[is_included_column] 
				FROM sys.[tables] AS T
					INNER JOIN sys.[indexes] I ON T.[object_id] = I.[object_id]  
					INNER JOIN sys.[index_columns] IC ON I.[object_id] = IC.[object_id] 
					INNER JOIN sys.[all_columns] AC ON T.[object_id] = AC.[object_id] AND IC.[column_id] = AC.[column_id] 
				WHERE T.[is_ms_shipped] = 0 AND I.[type_desc] <> 'HEAP' 
					AND I.name = 'PPS_USER_SESSION_COOKIE' AND AC.name = 'DISABLED' AND is_included_column=1)
BEGIN
	CREATE UNIQUE INDEX PPS_USER_SESSION_COOKIE_1 ON PPS_USER_SESSIONS (SESSION_COOKIE, DATE_CREATED DESC) INCLUDE (DISABLED) WITH (FILLFACTOR=80, PAD_INDEX=ON, SORT_IN_TEMPDB=ON);
	
	IF EXISTS(SELECT 1 FROM sys.indexes WHERE name = N'PPS_USER_SESSION_COOKIE') 
	BEGIN
		DROP INDEX PPS_USER_SESSION_COOKIE ON PPS_USER_SESSIONS
	END
	EXEC sp_rename N'PPS_USER_SESSIONS.PPS_USER_SESSION_COOKIE_1', N'PPS_USER_SESSION_COOKIE', N'INDEX'
END
GO
-- safety measure, in case index remained alive
IF EXISTS(SELECT 1 FROM sys.indexes WHERE name = N'PPS_USER_SESSION_COOKIE_1') 
BEGIN
	PRINT 'Index PPS_USER_SESSION_COOKIE_1 will be now dropped. Please re-run this script'
	DROP INDEX PPS_USER_SESSION_COOKIE_1 ON PPS_USER_SESSIONS
END
GO
PRINT 'OK'
GO
----------------------------------------------------------------------------------------------------------------------------------
--END  Bug: CONN-4083634
----------------------------------------------------------------------------------------------------------------------------------

------------------------------------------------------------------------------------------------------------------------------
--BEGIN  Bug: #4083574 - EAR : Time Zone Glitch in Events Module
------------------------------------------------------------------------------------------------------------------------------
IF NOT EXISTS (SELECT * FROM PPS_ENUM_TIME_ZONES WHERE TIME_ZONE_ID = 55)
BEGIN
  INSERT INTO PPS_ENUM_TIME_ZONES (TIME_ZONE_ID, NAME, JAVA_ID) 
  VALUES (55, '(GMT-04:00) Georgetown, La Paz', 'America/La_Paz');
END
ELSE
BEGIN
  UPDATE PPS_ENUM_TIME_ZONES SET JAVA_ID = 'America/La_Paz' WHERE TIME_ZONE_ID = 55 AND JAVA_ID = 'America/La Paz';
END
GO
------------------------------------------------------------------------------------------------------------------------------
--END Bug: #4083574 - EAR : Time Zone Glitch in Events Module
------------------------------------------------------------------------------------------------------------------------------

--------------------------------------
-- End of updates
--------------------------------------

--------------------------------------------------------------------
-- BEGIN REFRESH block
--
-- Recompile SPs, views and other objects that need to be recompiled
-- Please DO NOT change following lines
--------------------------------------------------------------------
GO
IF CURSOR_STATUS('global', 'ObjectCursor') >= -1
BEGIN
	DEALLOCATE ObjectCursor;
END
GO

DECLARE @Name nvarchar(1000);
DECLARE @Sql nvarchar(1000);
DECLARE @Result int;

DECLARE ObjectCursor CURSOR FAST_FORWARD FOR
	SELECT SCHEMA_NAME(o.schema_id) + '.[' + OBJECT_NAME(o.object_id) + ']'
	FROM sys.objects o 
	WHERE type_desc IN ('SQL_STORED_PROCEDURE', 'SQL_TRIGGER', 'SQL_SCALAR_FUNCTION', 'SQL_TABLE_VALUED_FUNCTION',
								'SQL_INLINE_TABLE_VALUED_FUNCTION',	'VIEW')
	AND ISNULL(OBJECTPROPERTY(o.object_id,'IsSchemaBound'), 0) = 0	 -- don't check schemabinding they don't like it

OPEN ObjectCursor;
FETCH NEXT FROM ObjectCursor INTO @Name;

WHILE @@FETCH_STATUS = 0
BEGIN
   SET @Sql = N'EXEC sp_refreshsqlmodule ''' + @Name + '''';
   --PRINT @Sql;

   BEGIN TRY
		EXEC @Result = sp_executesql @Sql;
		IF @Result <> 0 RAISERROR('Failed', 16, 1);
   END TRY
   BEGIN CATCH
		PRINT @Sql
      PRINT 'The module ''' + @Name + ''' does not compile.';
   IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION;
    END CATCH

    FETCH NEXT FROM ObjectCursor INTO @Name;
END

CLOSE ObjectCursor;
DEALLOCATE ObjectCursor;
GO

-------------------------------------------------------------------------------
-- Change the version number to match the file build number below
-- MINOR_RELEASE is tantamount to Service Pack
-- The REVISION field should never really be set to anything other than 0 in the DB update scripts context

UPDATE PPS_DATABASE_VERSION SET 
	MAJOR_RELEASE = 9, 
	MINOR_RELEASE = 5, 
	[UPDATE] = 5, 
	REVISION = 0
GO

EXECUTE updateLogger '$Id: //depot/main/AdobeConnect/installers/patches/9.5.4_9.5.5/update_9_5_5_0.sql#2 $', '$Change: 1337535 $', 'Finish';
GO

